<?php

class Controller
{
    private Connection $con;

    /**
     * @param Connection $con
     */
    function __construct(Connection $con) {
        $this->con=$con;
        session_start();
        try{
            echo "controller";
            global $rep, $vues, $error;
            $action=$_REQUEST['action'];
            switch($action) {
                case NULL:
                    require ($rep.$vues['main']);
                    break;
                case "signUp":
                    $this->signUp();
                    break;
                case "login":
                    $this->login();
                    break;
                case "goToPresentation":
                    $this->goToPresentation();
                    break;
                case "goToHome":
                    $this->goToHome();
                    break;
                case "goToLogin":
                    $this->goToLogin();
                    break;
                case "goToSignUp":
                    $this->goToSignUp();
                    break;
                case "goToEnigme":
                    $this->goToEnigme();
                    break;
            }
        } catch (PDOException $e)
        {
            $error = $e->getMessage();
            require ($rep.$vues['erreur']);
        }
    }

    private function signUp() {
        global $rep, $vues, $sel, $error;
        try {
            $gateway = new JoueurGateway($this->con);
            $validation = new Validation();
            if (! $validation->ValidateEmail($_REQUEST['email'])) {
                $error = "Email invalides.";
                throw (new Exception("Email non valide"));
            }
            if(! $validation->ValidateUsername($_REQUEST['username'])){
                $error = "Nom d'utilisateur invalides. Il ne doit pas contenir de caractère spéciaux.";
                throw(new Exception("Pseudo non valide"));
            }
            if(! $validation->ValidatePassword($_REQUEST['password'])){
                $error = "Mots de passe invalides. Il ne doit pas dépasser 100 caractères.";
                throw(new Exception("Mot de passe non valide"));
            }
            $j = $gateway->getJoueurByEmail($_REQUEST['email']);
            if ($j != null) {
                $error = "Email déjà utilisé.";
                throw (new Exception("Email déjà utilisé"));
            }
            $password = password_hash($_REQUEST['password'], PASSWORD_DEFAULT);
            $joueur = new Joueur($_REQUEST['email'], $_REQUEST['username'], $password);
            $gateway->insert($joueur);
            $_SESSION['connected'] = 'true';
            require ($rep.$vues['main']);
        }catch (Exception $e){
            require($rep.$vues['erreur']);
        }
    }
    private function login(){
        global $rep, $vues, $sel, $error;
        try {
            $gateway = new JoueurGateway($this->con);
            $joueur = $gateway->getJoueurByEmail($_REQUEST['email']);
            if ($joueur->getEmail() == null){
                $error = "Joueur non trouvé.";
                throw new Exception("Joueur introuvable");
            }
            $mdp = $gateway->getMdpByEmail($_REQUEST['email']);
            if (password_verify($mdp, $_REQUEST['password'])){
                $error = "Mot de passe incorrect.";
                throw new Exception("Mot de passe invalide");
            }
            $_SESSION['connected'] = 'true';
            require ($rep.$vues['main']);
        }catch (Exception $e){
            require($rep.$vues['erreur']);
        }
    }
    // require error page with given message

    private function goToPresentation() {
        global $rep, $vues, $error;
        try {
            require ($rep.$vues['presenation']);
        }catch (Exception $e){
            $error = "Erreur Inconnue";
            require($rep.$vues['erreur']);
        }
    }

    private function goToHome() {
        global $rep, $vues, $error;
        try {
            require ($rep.$vues['main']);
        }catch (Exception $e){
            $error = "404";
            require($rep.$vues['erreur']);
        }
    }

    private function goToLogin() {
        global $rep, $vues, $error;
        try {
            require ($rep.$vues['login']);
        }catch (Exception $e){
            $error = "404";
            require($rep.$vues['erreur']);
        }
    }

    private function goToSignUp() {
        global $rep, $vues, $error;
        try {
            require ($rep.$vues['signUp']);
        }catch (Exception $e){
            $error = "404";
            require($rep.$vues['erreur']);
        }
    }

    private function goToEnigme() {
        global $rep, $vues, $error;
        try {
            require ($rep.$vues['enigme']);
        }catch (Exception $e){
            $error = "404";
            require($rep.$vues['erreur']);
        }
    }
}